<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" indent="yes" encoding="ASCII"/>
<xsl:strip-space elements="*"/>

<!--
TODO:
  + include a link to the PDF version.
  - add a background image (duff's device!)
  - add styling
  - encrypt email address or show as a png. Use resume@9stmaryrd.com.
    - test resume email address again
  + improve LaTeX and BibTeX styling.
  - add meta tags.
  + use an asterisk for the footnote.
-->

<xsl:template match="/resume"><html>
<head>
<meta http-equiv="X-UA-Compatible" content="IE=7"/>
<title>Paul A. Jungwirth&#8217;s R&#233;sum&#233;</title>
<link href="resume.css" rel="stylesheet" type="text/css"/>
<style type="text/css">
sup {
	font-size: smaller;
	font-weight: normal;
	vertical-align: baseline;
	position: relative;
	bottom: 0.33em;
}
sub {
    font-size: smaller;
    vertical-align: baseline;
    position: relative;
    bottom: -0.25em;
}
</style>
<script type="text/javascript" src="DD_roundies.js"></script>
<script type="text/javascript">
DD_roundies.addRule(".rounded-corners", "20px", true);
</script>
</head>
<body>
	<h1><xsl:apply-templates select="name" mode="unescape"/></h1>
	<div id="pdf-link">
	(<a href="/paul_jungwirth.pdf">PDF Version</a>)
	</div>
	<div id="personal-info" class="rounded-corners">
	<div id="address">
		<xsl:apply-templates select="street" mode="unescape"/><br/>
		<xsl:apply-templates select="city" mode="unescape"/>
	</div>
	<div id="contact">
		<xsl:apply-templates select="phone" mode="unescape"/><br/>
		<xsl:apply-templates select="email" mode="unescape"/>
	</div>
	</div>
	<!--
	<div id="philosophy" class="rounded-corners">
		Blah blah blah
	</div>
	-->
<xsl:apply-templates/>
</body>
</html>
</xsl:template>


<xsl:template match="skills">
<h2>I Can</h2>
<div id="skills" class="rounded-corners">
<ul>
<xsl:apply-templates/>
</ul>
</div>
</xsl:template>

<xsl:template match="skill[@html='true']">
	<li><xsl:apply-templates select="." mode="unescape"/></li>
</xsl:template>


<xsl:template match="techs">
<h2>I Know</h2>
<div id="techs" class="rounded-corners">
<table id="tech-table">
<xsl:apply-templates select="tech-type"/>
</table>
<xsl:apply-templates select="footnote-message"/>
</div>
</xsl:template>

<xsl:template match="tech-type[@html='true']">
	<tr>
    <td><xsl:apply-templates select="tech-type-name" mode="unescape"/></td>
    <td><xsl:for-each select="tech">
		<xsl:if test="position() > 1">, </xsl:if>
		<xsl:apply-templates select="." mode="unescape"/></xsl:for-each></td>
	</tr>
</xsl:template>


<xsl:template name="pick-footnote-mark">
<xsl:choose>
	<xsl:when test="@fn='1'">*</xsl:when>
	<xsl:when test="@fn='2'">&#8224;</xsl:when>
	<xsl:when test="@fn='3'">&#8225;</xsl:when>
</xsl:choose>
</xsl:template>

<xsl:template match="footnote-message">
<div class="footnote"><sup><xsl:call-template name="pick-footnote-mark"/></sup><xsl:apply-templates select="." mode="unescape"/></div>
</xsl:template>


<xsl:template match="jobs">
<h2>I Was</h2>
<div id="jobs" class="rounded-corners">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="job[@html='true']">
<h3><xsl:apply-templates select="job-title" mode="unescape"/></h3>
<div class="company"><xsl:apply-templates select="job-company" mode="unescape"/></div>
<div class="location"><xsl:apply-templates select="job-location" mode="unescape"/></div>
<div class="period"><xsl:apply-templates select="job-period" mode="unescape"/></div>
<ul>
	<xsl:apply-templates/>
</ul>
</xsl:template>

<xsl:template match="job-duty[@html='true']">
	<li><xsl:apply-templates select="." mode="unescape"/></li>
</xsl:template>


<xsl:template match="studies">
<h2>I Studied</h2>
<div id="schools" class="rounded-corners">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="study[@html='true']">
<h3><xsl:apply-templates select="study-topic" mode="unescape"/></h3>
<div class="school"><xsl:apply-templates select="school-name" mode="unescape"/></div>
<div class="location"><xsl:apply-templates select="school-location" mode="unescape"/></div>
<div class="period"><xsl:apply-templates select="school-period" mode="unescape"/></div>
<ul>
	<xsl:apply-templates/>
</ul>
</xsl:template>

<xsl:template match="study-note">
	<li><xsl:apply-templates select="." mode="unescape"/></li>
</xsl:template>


<xsl:template match="others">
<h2>I Also</h2>
<ul>
	<xsl:apply-templates/>
</ul>
</xsl:template>

<xsl:template match="other[@html='true']">
	<li><xsl:apply-templates select="." mode="unescape"/></li>
</xsl:template>



<!-- Use these templates to get special characters -->
<xsl:template match="nohyphen"><xsl:apply-templates/></xsl:template>
<xsl:template match="*" mode="unescape"><xsl:apply-templates/></xsl:template>
<xsl:template match="ndash">&#8211;</xsl:template>
<xsl:template match="latex">L<sup>A</sup>T<sub>E</sub>X</xsl:template>
<xsl:template match="bibtex">BibT<sub>E</sub>X</xsl:template>
<xsl:template match="dollar">$</xsl:template>
<xsl:template match="amp">&amp;</xsl:template>
<xsl:template match="minspace">&#0160;</xsl:template>
<xsl:template match="rsquo">&#8217;</xsl:template>
<xsl:template match="hash">#</xsl:template>
<xsl:template match="footnote"><xsl:if test="@fn != ''"><sup><xsl:call-template name="pick-footnote-mark"/></sup></xsl:if></xsl:template>

<xsl:template match="*"/>

</xsl:stylesheet>
